# About common

<img src="https://gitlab.com/octomy/common/-/raw/master/design/common-logo-1024.png" width="20%"/>

Common files for octomy python projects


Common is [available on gitlab](https://gitlab.com/octomy/common).
Common is [available in PyPI](https://pypi.org/project/common/).

```shell
# Install common into your current Python environment
pip install octomy-common

```




